@@ -1,14 +1,12 @@
 class NoneArgumentError(ValueError):
-    """Exception on None argument
-    """
+    """Exception on None argument"""
 
     def __init__(self, message: str):
         super().__init__(message)
 
 
 class InvalidOperationError(Exception):
-    """Exception on invalid operations
-    """
+    """Exception on invalid operations"""
 
     def __init__(self, message: str = ""):
         super().__init__(message)
